@@ -135,7 +135,7 @@ void TextToSpeechPrivate::say(const QString &text) {
 void TextToSpeechPrivate::setVolume(int volume) {
 	// Check for setVolume: availability. It's only available on 10.5+.
 	if ([[m_synthesizerHelper synthesizer] respondsToSelector:@selector(setVolume:)]) {
-		[[m_synthesizerHelper synthesizer] setVolume:volume / 100.0f];
+		[[m_synthesizerHelper synthesizer] setVolume:(float)volume / 100.0f];
 	}
 }
 
